summaryrefslogtreecommitdiffstats
path: root/kutils/ksettings/dispatcher.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:20:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:20:05 -0600
commitb19ddece21e102b8e4b292037ca7578f60b128fe (patch)
tree6572ca25aba80849cdfa7578bbbc9121d23afbc3 /kutils/ksettings/dispatcher.h
parente729c6d549f12e27b358a1dad04ff254c033ac71 (diff)
downloadtdelibs-b19ddece21e102b8e4b292037ca7578f60b128fe.tar.gz
tdelibs-b19ddece21e102b8e4b292037ca7578f60b128fe.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'kutils/ksettings/dispatcher.h')
-rw-r--r--kutils/ksettings/dispatcher.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kutils/ksettings/dispatcher.h b/kutils/ksettings/dispatcher.h
index 52829f9e7..c04a41b99 100644
--- a/kutils/ksettings/dispatcher.h
+++ b/kutils/ksettings/dispatcher.h
@@ -28,7 +28,7 @@ class TQCString;
class TQSignal;
class TQStrList;
template<class T> class KStaticDeleter;
-class KInstance;
+class TDEInstance;
class KConfig;
namespace KSettings
@@ -61,17 +61,17 @@ class KUTILS_EXPORT Dispatcher : public TQObject
/**
* Register a slot to be called when the configuration for the instance
* has changed. @p instance is the KInstance object
* that is passed to KGenericFactory (if it is used). You can query
* it with KGenericFactory<YourClassName>::instance().
* instance->instanceName() is also the same name that is put into the
* .desktop file of the KCMs for the X-TDE-ParentComponents.
*
* @param instance The KInstance object
* @param recv The object that should receive the signal
* @param slot The slot to be called: TQT_SLOT( slotName() )
*/
- void registerInstance( KInstance * instance, TQObject * recv, const char * slot );
+ void registerInstance( TDEInstance * instance, TQObject * recv, const char * slot );
/**
* @return the KConfig object that belongs to the instanceName
@@ -85,10 +85,10 @@ class KUTILS_EXPORT Dispatcher : public TQObject
TQStrList instanceNames() const;
//X /**
//X * @return The KInstance object belonging to the instance name you pass
//X * (only works for registered instances of course).
//X */
-//X KInstance * instanceForName( const TQCString & instanceName );
+//X TDEInstance * instanceForName( const TQCString & instanceName );
public slots:
/**
@@ -116,7 +116,7 @@ class KUTILS_EXPORT Dispatcher : public TQObject
static Dispatcher * m_self;
struct InstanceInfo {
- KInstance * instance;
+ TDEInstance * instance;
TQSignal * signal;
int count;
};
@@ -61,17 +61,17 @@ class KUTILS_EXPORT Dispatcher : public TQObject
/**
* Register a slot to be called when the configuration for the instance
- * has changed. @p instance is the KInstance object
+ * has changed. @p instance is the TDEInstance object
* that is passed to KGenericFactory (if it is used). You can query
* it with KGenericFactory<YourClassName>::instance().
@@ -61,17 +61,17 @@ class KUTILS_EXPORT Dispatcher : public TQObject
* .desktop file of the KCMs for the X-TDE-ParentComponents.
*
- * @param instance The KInstance object
+ * @param instance The TDEInstance object
* @param recv The object that should receive the signal
* @param slot The slot to be called: TQT_SLOT( slotName() )
@@ -85,10 +85,10 @@ class KUTILS_EXPORT Dispatcher : public TQObject
TQStrList instanceNames() const;
//X /**
-//X * @return The KInstance object belonging to the instance name you pass
+//X * @return The TDEInstance object belonging to the instance name you pass
//X * (only works for registered instances of course).
//X */